AppleAuthInfo class abstract

Authentication info for Sign in with Apple.

Constructors

AppleAuthInfo({required String userIdentifier, String? email, required String fullName, required String nickname, required String identityToken, required String authorizationCode})
factory
AppleAuthInfo.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

authorizationCode ↔ String
Authorization code associated with the sign in.
getter/setter pair
email ↔ String?
User email, if available.
getter/setter pair
fullName ↔ String
Full name of the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identityToken ↔ String
Identity token associated with the sign in.
getter/setter pair
nickname ↔ String
Nickname or first name of the user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIdentifier ↔ String
The unique user identifier.
getter/setter pair

Methods

copyWith({String? userIdentifier, String? email, String? fullName, String? nickname, String? identityToken, String? authorizationCode}) → AppleAuthInfo
Returns a shallow copy of this AppleAuthInfo with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited