EmailFailedSignInTable class

Constructors

EmailFailedSignInTable({TableRelation? tableRelation})

Properties

columns List<Column>
List of Column used by the table.
no setter
email ↔ ColumnString
Email attempting to sign in with.
latefinal
hasColumnMapping bool
Cached flag indicating whether any columns have explicit column names that differ from their field names. Computed lazily on first access.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<int?>
The database id.
latefinalinherited
ipAddress ↔ ColumnString
The IP address of the sign in attempt.
latefinal
managedColumns List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
queryPrefix String
Query prefix for Columns of the table.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
Name of the table as used in the database.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
time ↔ ColumnDateTime
The time of the sign in attempt.
latefinal
updateTable EmailFailedSignInUpdateTable
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited