EmailReset class abstract

Database bindings for an email reset.

Constructors

EmailReset({int? id, required int userId, required String verificationCode, required DateTime expiration})
factory
EmailReset.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

expiration ↔ DateTime
The expiration time for the password reset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table<int?>
The table that this row belongs to.
no setter
userId ↔ int
The id of the user that is resetting his/her password.
getter/setter pair
verificationCode ↔ String
The verification code for the password reset.
getter/setter pair

Methods

copyWith({int? id, int? userId, String? verificationCode, DateTime? expiration}) → EmailReset
Returns a shallow copy of this EmailReset with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

t → EmailResetTable
final

Static Methods

include() → EmailResetInclude
includeList({WhereExpressionBuilder<EmailResetTable>? where, int? limit, int? offset, OrderByBuilder<EmailResetTable>? orderBy, OrderByListBuilder<EmailResetTable>? orderByList, EmailResetInclude? include}) → EmailResetIncludeList

Constants

db → const EmailResetRepository