Protocol class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
decode <T > (String data , [Type ? t ])
→ T
Decodes the provided json String to an object of type t or T.
inherited
decodeWithType (String data )
→ Object ?
Decodes the provided json String if it has been encoded with
encodeWithType.
inherited
deserialize <T > (dynamic data , [Type ? t ])
→ T
Deserialize the provided json data to an object of type t or T.
deserializeByClassName (Map <String , dynamic > data )
→ dynamic
Deserialize the provided json data by using the className stored in the data.
encodeWithType (Object ? object , {bool formatted = false })
→ String
Encode the provided object to a json-formatted String , include class
name so that it can be decoded even if the class is unknown.
If formatted is true, the output will be formatted with two spaces
indentation.
inherited
encodeWithTypeForProtocol (Object ? object , {bool formatted = false })
→ String
Encode the provided object to a Json-formatted String , including the
class name so that it can be decoded even if the class is unknown.
If formatted is true, the output will be formatted with two spaces
indentation. If object implements ProtocolSerialization interface, then
toJsonForProtocol will be used instead of the toJson method.
inherited
getClassNameForObject (Object ? data )
→ String ?
Get the className for the provided object.
getModuleName ()
→ String
The name of the module that defines the serialization.
getTableForType (Type t )
→ Table?
Maps Type s to subclasses of Table.
getTargetTableDefinitions ()
→ List <TableDefinition >
The desired structure of the database.
mapRecordToJson (Record ? record )
→ Map <String , dynamic > ?
Maps any Records known to this Protocol to their JSON representation
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
wrapWithClassName (Object ? data )
→ Map <String , dynamic >
Wraps serialized data with its class name so that it can be deserialized
with deserializeByClassName.
inherited
serverpod_auth_server 3.5.0-beta.2