copyWith abstract method
Returns a shallow copy of this UserImage with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
UserImage copyWith({
int? id,
int? userId,
int? version,
String? url,
});
Returns a shallow copy of this UserImage with some or all fields replaced by the given arguments.
@_is.useResult
UserImage copyWith({
int? id,
int? userId,
int? version,
String? url,
});