UserInfoTable class

Constructors

UserInfoTable({TableRelation? tableRelation})

Properties

blocked ↔ ColumnBool
True if the user is blocked from signing in.
latefinal
columns → List<Column>
List of Column used by the table.
no setter
created ↔ ColumnDateTime
The time when this user was created.
latefinal
email ↔ ColumnString
The email of the user.
latefinal
fullName ↔ ColumnString
The full name of the user.
latefinal
hasColumnMapping → bool
Cached flag indicating whether any columns have explicit column names that differ from their field names. Computed lazily on first access.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<int?>
The database id.
latefinalinherited
imageUrl ↔ ColumnString
A URL to the user's avatar.
latefinal
managedColumns → List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
queryPrefix → String
Query prefix for Columns of the table.
no setterinherited
quotedTableName → String
tableName quoted for the current dialect. Prefer it over tableName in raw SQL, since dialects quote schemas differently.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
Schema part of tableName, or null when the name is unqualified.
latefinalinherited
scopeNames ↔ ColumnSerializable<List<String>>
List of scopes that this user can access.
latefinal
tableName → String
Name of the table as used in the database, optionally qualified as schema.table.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
unqualifiedTableName → String
tableName with the schema removed.
latefinalinherited
updateTable ↔ UserInfoUpdateTable
latefinal
userIdentifier ↔ ColumnString
Unique identifier of the user, may contain different information depending on how the user was created.
latefinal
userName ↔ ColumnString
The first name of the user or the user's nickname.
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited