EmailResetRepository class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<EmailResetTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<EmailReset> rows, {Transaction? transaction}) Future<List<EmailReset>>
Deletes all EmailResets in the list and returns the deleted rows. This is an atomic operation, meaning that if one of the rows fail to be deleted, none of the rows will be deleted.
deleteRow(DatabaseSession session, EmailReset row, {Transaction? transaction}) Future<EmailReset>
Deletes a single EmailReset.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<EmailResetTable> where, Transaction? transaction}) Future<List<EmailReset>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<EmailResetTable>? where, int? limit, int? offset, OrderByBuilder<EmailResetTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailResetTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<EmailReset>>
Returns a list of EmailResets matching the given query parameters.
findById(DatabaseSession session, int id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<EmailReset?>
Finds a single EmailReset by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<EmailResetTable>? where, int? offset, OrderByBuilder<EmailResetTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailResetTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<EmailReset?>
Returns the first matching EmailReset matching the given query parameters.
insert(DatabaseSession session, List<EmailReset> rows, {Transaction? transaction, bool ignoreConflicts = false}) Future<List<EmailReset>>
Inserts all EmailResets in the list and returns the inserted rows.
insertRow(DatabaseSession session, EmailReset row, {Transaction? transaction}) Future<EmailReset>
Inserts a single EmailReset and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<EmailResetTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait}) Future<void>
Acquires row-level locks on EmailReset rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<EmailReset> rows, {ColumnSelections<EmailResetTable>? columns, Transaction? transaction}) Future<List<EmailReset>>
Updates all EmailResets in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<EmailResetUpdateTable> columnValues, Transaction? transaction}) Future<EmailReset?>
Updates a single EmailReset by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, EmailReset row, {ColumnSelections<EmailResetTable>? columns, Transaction? transaction}) Future<EmailReset>
Updates a single EmailReset. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<EmailResetUpdateTable> columnValues, required WhereExpressionBuilder<EmailResetTable> where, int? limit, int? offset, OrderByBuilder<EmailResetTable>? orderBy, OrderByListBuilder<EmailResetTable>? orderByList, bool orderDescending = false, Transaction? transaction}) Future<List<EmailReset>>
Updates all EmailResets matching the where expression with the specified columnValues. Returns the list of updated rows.

Operators

operator ==(Object other) bool
The equality operator.
inherited