PasswordValidationFailed class final
Validation failed because the computed password hash did not match the stored hash.
- Inheritance
-
- Object
- PasswordValidationResult
- PasswordValidationFailed
Constructors
- PasswordValidationFailed({required String passwordHash, required String storedHash})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- passwordHash → String
-
The hash computed from the provided password using the configured
password hashing algorithm.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storedHash → String
-
The hash retrieved from storage (e.g., database) for the user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited