UserInfoRepository class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
count (DatabaseSession session , {WhereExpressionBuilder<UserInfoTable > ? where , int ? limit , Transaction? transaction })
→ Future <int >
Counts the number of rows matching the where expression. If omitted,
will return the count of all rows in the table.
delete (DatabaseSession session , List <UserInfo > rows , {Transaction? transaction })
→ Future <List <UserInfo > >
Deletes all UserInfo s in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
deleteRow (DatabaseSession session , UserInfo row , {Transaction? transaction })
→ Future <UserInfo >
Deletes a single UserInfo .
deleteWhere (DatabaseSession session , {required WhereExpressionBuilder<UserInfoTable > where , Transaction? transaction })
→ Future <List <UserInfo > >
Deletes all rows matching the where expression.
find (DatabaseSession session , {WhereExpressionBuilder<UserInfoTable > ? where , int ? limit , int ? offset , OrderByBuilder<UserInfoTable > ? orderBy , bool orderDescending = false , OrderByListBuilder<UserInfoTable > ? orderByList , Transaction? transaction , LockMode? lockMode , LockBehavior? lockBehavior })
→ Future <List <UserInfo > >
Returns a list of UserInfo s matching the given query parameters.
findById (DatabaseSession session , int id , {Transaction? transaction , LockMode? lockMode , LockBehavior? lockBehavior })
→ Future <UserInfo ? >
Finds a single UserInfo by its id or null if no such row exists.
findFirstRow (DatabaseSession session , {WhereExpressionBuilder<UserInfoTable > ? where , int ? offset , OrderByBuilder<UserInfoTable > ? orderBy , bool orderDescending = false , OrderByListBuilder<UserInfoTable > ? orderByList , Transaction? transaction , LockMode? lockMode , LockBehavior? lockBehavior })
→ Future <UserInfo ? >
Returns the first matching UserInfo matching the given query parameters.
insert (DatabaseSession session , List <UserInfo > rows , {Transaction? transaction , bool ignoreConflicts = false })
→ Future <List <UserInfo > >
Inserts all UserInfo s in the list and returns the inserted rows.
insertRow (DatabaseSession session , UserInfo row , {Transaction? transaction })
→ Future <UserInfo >
Inserts a single UserInfo and returns the inserted row.
lockRows (DatabaseSession session , {required WhereExpressionBuilder<UserInfoTable > where , required LockMode lockMode , required Transaction transaction , LockBehavior lockBehavior = _i1.LockBehavior.wait })
→ Future <void >
Acquires row-level locks on UserInfo rows matching the where expression.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
update (DatabaseSession session , List <UserInfo > rows , {ColumnSelections<UserInfoTable > ? columns , Transaction? transaction })
→ Future <List <UserInfo > >
Updates all UserInfo s in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
updateById (DatabaseSession session , int id , {required ColumnValueListBuilder<UserInfoUpdateTable > columnValues , Transaction? transaction })
→ Future <UserInfo ? >
Updates a single UserInfo by its id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
updateRow (DatabaseSession session , UserInfo row , {ColumnSelections<UserInfoTable > ? columns , Transaction? transaction })
→ Future <UserInfo >
Updates a single UserInfo . The row needs to have its id set.
Optionally, a list of columns can be provided to only update those
columns. Defaults to all columns.
updateWhere (DatabaseSession session , {required ColumnValueListBuilder<UserInfoUpdateTable > columnValues , required WhereExpressionBuilder<UserInfoTable > where , int ? limit , int ? offset , OrderByBuilder<UserInfoTable > ? orderBy , OrderByListBuilder<UserInfoTable > ? orderByList , bool orderDescending = false , Transaction? transaction })
→ Future <List <UserInfo > >
Updates all UserInfo s matching the where expression with the specified columnValues.
Returns the list of updated rows.
serverpod_auth_server 3.4.3